#include "../cmain.f"
#include "chookHybAS.f"
#include "../ctemplCeren.f"
      subroutine time(xxx)
      integer xxx
      xxx = 1
      end
      
c  *************************************** hook for Beginning of a Run
c  * At this moment, all (system-level) initialization for this run
c  * has been ended.  After this routine is executed, the system goes into the
c  * event creation loop.
c  *
      subroutine chookBgRun
      implicit none
#include "Zmanagerp.h"

 
c         If you feel writing the parameters on stderr is
c         a bother, comment out the next or
c         use other device than ErrorOut.
c         Also you may comment out all output routines below.

c            namelist output
      call cwriteParam(ErrorOut, 0)
c            primary information
      call cprintPrim(ErrorOut)
c            observation level information
      call cprintObs(ErrorOut)
      end


c     *********************************** hook for Beginning of  1 event
c     *  All system-level initialization for 1 event generation has been
c     *  eneded at this moment.
c     *  After this is executed, event generation starts.
c     *
      subroutine chookBgEvent
      implicit none
#include "Ztrack.h"
#include "Zobs.h"
#include "Zobsv.h"
      include "Zprivate.h"

      integer i, j
      sume = 0
      sumepi0 = 0
      nc = 0
      ncpi0= 0 
      call cqUhookr(1, cut)
      end
  

c     ************************************ hook for observation
c     *  One particle information is brought here by the system.
c     *  All information of the particle is in aTrack
c     *
      subroutine chookObs(aTrack, id)
c
c     Note that every real variable is in double  precision so
c     that you may output it in sigle precision to save the memory.
c     In some cases it is essential to put it in sigle (say,
c     for gnuplot).
c 
      implicit none
#include "Ztrack.h"
#include  "Zcode.h"
      include "Zprivate.h"

      integer id  ! input.  1 ==> aTrack is going out from
c                                 outer boundery.
c                           2 ==> reached at an observation level
c                           3 ==> reached at inner boundery.
      record /track/ aTrack
c
c     For id =2, you need not output the z value, because it is always
c     0 (within the computational accuracy).
c
c      if(id .eq. 2 .and.  aTrack.vec.coszenith .gt. 0 ) then
c         if(aTrack.p.code .le. 3) then
c            nc(aTrack.p.code, aTrack.where) = 
c     *        nc(aTrack.p.code, aTrack.where) +1
c         endif
c      endif
c            output typical quantities.
c        write(*, '(3i5, ) 
c     *  aTrack.where,   !  observation level. integer*2.  1 is highest.
c     *  aTrack.p.code,    !  ptcl code.  integer*2.
c     *  aTrack.p.charge,  !  charge,  integer*2 
c     *  sngl(aTrack.t), !  relateive arrival time in nsec (NOT sec).
c                        !  if TimeStructure is F, nonsense.
c     *  sngl(aTrack.p.fm.p(4))  ! total energy in GeV.
c     *  sngl(aTrack.pos.xyz.r(1)), sngl(aTrack.pos.xyz.r(2)), !  x, y in m
c     *  sngl(aTrack.vec.w.r(1)),  ! direc. cos.x in the current detector system.
c     *  sngl(aTrack.vec.w.r(2)),  ! direc. cos.y
c     *  sngl(aTrack.vec.w.r(3)),  ! direc. cos.z
c     *  sngl(aTrack.vec.coszenith) ! cos of zenith angle
c      endif
c         you may need in some case other information such as
c       aTrack.p.subcode   ! sub code of the particle integer*2
c       aTrack.p.mass      ! mass 
c       aTrack.wgt         ! weight of the particle (may not be 1. if
                           ! ThinSampling =T)
c       aTrack.p.fm.p(1)      ! momentum x component.  Note. Momentum is
c                            given in the  Earth xyz system.

c       aTrack.p.fm.p(2)      !          y
c       aTrack.p.fm.p(3)      !          z

      end

c    *********************************** hook for end of 1 event
c    * At this moment, 1 event generation has been ended.
c    *
      subroutine chookEnEvent

      implicit none
#include "Ztrack.h"
#include "Ztrackv.h"
#include "Zobs.h"
#include "Zobsp.h"
#include "Zobsv.h"
      include "Zprivate.h"

      integer i, j
c      do i = 1, NoOfSites
c         do j = 1, 3
c            write(*, *) i, j, nc(j, i)
c         enddo
c      enddo
      if(ObserveAS) then
c                   electron size in B approx.
         write(*,*) 'e ', sngl(sume), nc, sngl(sumepi0), ncpi0
         do i = 1, NoOfASSites
            write(*, *) 's ',  sngl( ASDepthList(i)*0.1 ),
     *       sngl(ASObsSites(i).esize), sngl(ASObsSites(i).age)
         enddo
      endif
      write(*,*)
      end


c     ********************************* hook for end of a run
c     *  all events have been created or time lacks
c     *
      subroutine chookEnRun

      implicit none
#include "Ztrack.h"
#include "Ztrackp.h"




      end
c     ********************************* hook for trace
c     *  This is called only when trace > 60
c     *  User should manage the trace information here.
c     *  If you use this, you may need some output for trace
c     *  at the beginning of 1 event generatio and at the end of  1 event
c     *  generation so that you can identfy each event.
c     *
c     *
      subroutine chookTrace
            implicit none

#include  "Ztrack.h"
#include  "Ztrackv.h"
#include  "Ztrackp.h"
#include  "Zobs.h"
#include  "Zobsv.h"

      real*4 h1,  h2
c
c    Every time a particle is moved in the atmosphere, this routine is called,
c    if trace > 60. 
c         For a one track segment,
c     TrackBefMove  has  track information at the beginning of the segment.
c     MoveTrack    has   track information at the end of the segment.
c   
c     You can know the  information a track contains in the 
c     chookObs routine. (Note however, no conversion of coordinate
c     has been done.  The values are in the Earth xyz system.)
c     Besides quantities explained there, you can use, for a  given 'track'
c
c     atrack.pos.xyz.x, atrack.pos.xyz.y, atrack.pos.xyz.z    (x,y.z)
c     atrack.pos.radiallen   (distance from the center of the earth)
c     atrack.pos.depth       (vertical depth)
c     atrack.pos.height      (vertical heigth from sea level)  
c

      h1 = TrackBefMove.pos.height- ObsSites(NoOfSites).pos.height
      h2 = MovedTrack.pos.height - ObsSites(NoOfSites).pos.height

      end
c     ********************* this is the hook called when
c       an electron made an interaction.
c
      subroutine chookEInt(never)
            implicit none

#include  "Ztrack.h"
#include  "Ztrackv.h"
c  #include  "Ztrackp.h"
      
      integer never   ! input & output
      
c         don't make never = 1, if you want to get
c         information after an electron made interaction
c         if this is made non zero, this routine will never be called.
c
c   MovedTrack is the electron that made interaction
c   Pwork contains produced particles.
c   Nproduced has the number of particles in Pwork
c   IntInfArray(ProcessNo) contains the type of interaction
c
c        default setting
      never = 1
c
c        IntInfArray(ProcessNo).process will have one of
c       'brems', 'mscat', 'bscat',or  'anihi'
c
      end

c     ********************* this is the hook called when
c       a gamma ray made an interaction.
c
      subroutine chookGInt(never)
            implicit none

#include  "Ztrack.h"
#include  "Ztrackv.h"
c  #include  "Ztrackp.h"
      
      integer never   ! input & output
      
c         don't make never = 1, if you want to get
c         information after a gamma ray made interaction
c         if this is made non zero, this routine will never be called.
c
c   MovedTrack is the gamma that made interaction
c   Pwork contains produced particles.
c   Nproduced has the number of particles in Pwork
c   IntInfArray(ProcessNo) contains the type of interaction
c
c        default setting
      never = 1
c         IntInfArray(ProcessNo).process will have one of
c        'pair', 'comp', 'photoe' or 'photop'
c       
      end

c     ********************* this is the hook called when
c       non e-g particle made an interaction.
c
      subroutine chookNEPInt(never)
            implicit none

#include  "Ztrack.h"
#include  "Ztrackv.h"
#include  "Zcode.h"
      include "Zprivate.h"
      integer never   ! input & output
      integer i

c         don't make never = 1, if you want to get
c         information after a non-e-g particle  made interaction
c         if this is made non zero, this routine will never be called.
c
c   MovedTrack is the particle that made interaction
c   Pwork contains produced particles.
c   Nproduced has the number of particles in Pwork
c   IntInfArray(ProcessNo) contains the type of interaction
c
c        default setting is 1
      never = 0

c
c        IntInfArray(ProcessNo).process  will have
c             'coll' or 'decay'
      if(cut .lt. 1.) then
         if( IntInfArray(ProcessNo).process   .eq. 'coll' ) then
            do i = 1, Nproduced
c              for pions, kaons put E=mass if X > cut (for cut>0)
               if( Pwork(i).code .lt. knuc ) then
                  if( Pwork(i).fm.p(4) / MovedTrack.p.fm.p(4)
     *                 .gt. cut) then
                     sume = sume +  Pwork(i).fm.p(4)
                     nc = nc +1
                     if( Pwork(i).code .eq. kpion .and.
     *                   Pwork(i).charge .eq. 0 ) then
                        sumepi0 = sumepi0 + Pwork(i).fm.p(4)
                        ncpi0= ncpi0 + 1
                     endif
                     Pwork(i).fm.p(4) = Pwork(i).mass*1.1
                  endif
               endif
            enddo
         endif
      endif
      end

      
